@@ -27,6 +27,7 @@ from pathlib import Path
 from metomi.rose.config import ConfigLoader, ConfigDumper
 from cylc.rose.utilities import (
     ROSE_ORIG_HOST_INSTALLED_OVERRIDE_STRING,
+    deprecation_warnings,
     dump_rose_log,
     get_rose_vars_from_config_node,
     identify_templating_section,
@@ -37,7 +38,6 @@ from cylc.rose.utilities import (
     get_cli_opts_node,
     add_cylc_install_to_rose_conf_node_opts,
 )
-from cylc.flow import LOG
 from cylc.flow.hostuserutil import get_host
 
 
@@ -122,15 +122,7 @@ def get_rose_vars(srcdir=None, opts=None):
 
     # Load the raw config tree
     config_tree = rose_config_tree_loader(srcdir, opts)
-    # Warn if root-dir set in config
-    for string in list(config_tree.node):
-        if 'root-dir' in string:
-            LOG.warning(
-                'You have set "root-dir", which is not supported at '
-                'Cylc 8. Use `[install] symlink dirs` in global.cylc '
-                'instead.'
-                )
-            break
+    deprecation_warnings(config_tree)
 
     # Extract templatevars from the configuration
     get_rose_vars_from_config_node(
@@ -258,6 +250,7 @@ def rose_fileinstall(srcdir=None, opts=None, rundir=None):
             raise exc
         else:
             # Carry out imports.
+            import asyncio
             from metomi.rose.config_processor import ConfigProcessorsManager
             from metomi.rose.popen import RosePopener
             from metomi.rose.reporter import Reporter
@@ -274,7 +267,16 @@ def rose_fileinstall(srcdir=None, opts=None, rundir=None):
             fs_util = FileSystemUtil(event_handler)
             popen = RosePopener(event_handler)
 
-            # Process files
+            # Get an Asyncio loop if one doesn't exist:
+            #   Rose may need an event loop to invoke async interfaces,
+            #   doing this here incase we want to go async in cylc-rose.
+            # See https://github.com/cylc/cylc-rose/pull/130/files
+            try:
+                asyncio.get_event_loop()
+            except RuntimeError:
+                asyncio.set_event_loop(asyncio.new_event_loop())
+
+            # Process fileinstall.
             config_pm = ConfigProcessorsManager(event_handler, popen, fs_util)
             config_pm(config_tree, "file")
         finally:
